// ----------------------------------------------------------------------------
//  JumpData.cpp
// ----------------------------------------------------------------------------
#include "JumpData.h"
#include "Version.h"

// ----------------------------------------------------------------------------
JumpData::JumpData(const wxString& filename, const long posn, long lineNo)
// ----------------------------------------------------------------------------
{
    //ctor
    m_Filename = filename;
    m_Posn = posn;
    m_LineNo = lineNo;
}

// ----------------------------------------------------------------------------
JumpData::~JumpData()
// ----------------------------------------------------------------------------
{
    //dtor
    #if defined(LOGGING)
    LOGIT( _T("JumpData dtor"));
    #endif
}
